import subprocess

INCANTATION = ['git', 'rev-parse', 'HEAD']
DIRTY_INCANTATION = ['git', 'diff', 'HEAD']

class Git:
    @classmethod
    def sha(cls):
        output = subprocess.check_output(INCANTATION).strip()
        output = output.decode('utf-8')
        if cls.dirty():
            output += '-dirty' 
        return output

    @classmethod
    def dirty(cls):
        """ boolean of if changes have been made to present sha """
        output = subprocess.check_output(DIRTY_INCANTATION)
        return len(output.strip()) == 0



#!/usr/bin/env python
#
# usage:
#       testyoke pytest 
#       testyoke rspec
#
# automatically add appropriate parameter, grab file
#
import sys
from os import environ, path, getcwd
import argparse
import subprocess
from testyoke import Client, get_config
from testyoke.cvs import Git
from testyoke.client import ClientException
from testyoke.view import view
from . import main

if __name__ == '__main__':
    main()



import sys
from os import environ, path, getcwd
import subprocess
from testyoke import Client, get_config
from testyoke.cvs import Git
from testyoke.client import ClientException
from testyoke.view import view

XML_ARG = {
    'pytest': '--junitxml',
    'py.test': '--junitxml',
    'rspec': '--format RspecJunitFormatter  --out'
}

def main():
    report = '/tmp/obid'
    config = get_config()
    client = Client(config.project)
    sha = Git.sha()

    try:
        sha = client.sha(sha)
        print()
        print(view(sha))
        print()
    except ClientException:
        pass

    args = sys.argv[1:]

    if len(args) == 0:
        print("usage: testyoke pytest args")
        exit(1)

    args = args + [XML_ARG['pytest'], report]
    subprocess.call(args)

    if path.isfile(report):
        with open(report, 'r') as f:
            report = f.read()
            client.post(report, sha=sha.sha)
    else: 
        print(f"'{report}' is not a file.")



CONFIG = '.testyoke'


class Config:
    def __init__(self, **kwargs):
        self.api_key = kwargs.get('api_key')
        self.project = kwargs.get('project')
        self.consent = kwargs.get('consent')


# TODO testing
def get_config():
    """ local config for publishing data """
    try:
        with open(CONFIG, 'r') as ty:
            config = {}

            for line in ty:
               key, value = line.split('=')
               config[key.strip()] = value.strip()

            return Config(**config)

    except FileNotFoundError:
        print("No config file found, generating.")
        api_key = input("API KEY (http://testyoke.ipsumllc.com/):")
        project = getcwd().split('/')[-1]
        project = input(f"What's the name of this project? [default: {project}]") or project
        sha_consent = input("May testyoke collect git sha information? Y/n") or 'yes'

        with open(CONFIG, 'w') as ty:
            ty.write(f"api_key={api_key}\n")
            ty.write(f"project={project}\n")
            ty.write(f"consent={sha_consent}\n")

        return get_config()
